@@ -72,6 +72,7 @@
 
 static char    *hostName;
 static int      callBackSocket = -1;
+static pid_t    callBackPid = -1;
 static unsigned short    callBackPort = 0;
 static unsigned short    callBackPortRange = 1;
 
@@ -114,6 +115,7 @@ static server *parseConfig(const char *);
 static int cache_connect(server *);
 static int sayHello(int, ioTunnel *);
 static int create_data_socket(int *, unsigned short *);
+static int get_data_socket();
 static int ascii_open_conversation(struct vsp_node *);
 static int getDataMessage(struct vsp_node *);
 static void getRevision( revision * );
@@ -122,6 +124,7 @@ static void getPortRange();
 static int isActive();
 static ConfirmationBlock get_reply(int);
 static int name_invalid(char *);
+static server * url2srv(dcap_url *);
 
 #ifndef HAVE_HTONLL
     uint64_t  htonll(uint64_t);
@@ -275,15 +278,9 @@ cache_open(vsp_Node * node )
 		(node->asciiCommand == DCAP_CMD_OPENDIR ) ||
 		(node->asciiCommand == DCAP_CMD_TRUNC) ) {
 
-		m_lock(&bindLock);
-		if( callBackSocket == -1 ) {
-			if ( create_data_socket(&callBackSocket, &callBackPort) < 0) {
-				dc_debug(DC_ERROR, "Callback socket not created.");
-				m_unlock(&bindLock);
-				return -1;
-			}
+		if (get_data_socket()) {
+			return -1;
 		}
-		m_unlock(&bindLock);
 
 		node->data_port = callBackPort;
 	}
@@ -542,7 +539,7 @@ serverConnect(struct vsp_node * node)
 		lockMember();
 		if ((node->fd = getMember(dcache_host)) != -1) {
 
-			srv = parseConfig(node->url == NULL ? dcache_host : url2config(buffer, sizeof(buffer), node->url) );
+			srv = node->url == NULL ? parseConfig(dcache_host) : url2srv(node->url);
 			if (srv == NULL) {
 				unlockMember();
 				return -1;
@@ -560,7 +557,7 @@ serverConnect(struct vsp_node * node)
 
 		newQueue(0);
 		dc_debug(DC_INFO, "Creating a new control connection to %s.",dcache_host );
-		srv = parseConfig(node->url == NULL ? dcache_host : url2config(buffer, sizeof(buffer), node->url) );
+		srv = node->url == NULL ? parseConfig(dcache_host) : url2srv(node->url);
 
 		if (srv == NULL) {
 			unlockMember();
@@ -786,6 +783,26 @@ sayHello(int fd, ioTunnel *en)
 	return 0;
 }
 
+int
+get_data_socket()
+{
+       /* Initialize the callback socket */
+       /* Only performed once per PID (but must be done for every PID due to forks). */
+       m_lock(&bindLock);
+        pid_t curPid = getpid();
+       if( (curPid != callBackPid) || (callBackSocket == -1) ) {
+                callBackPort = 0;
+               if ( create_data_socket(&callBackSocket, &callBackPort) < 0) {
+                       dc_debug(DC_ERROR, "Callback socket not created.");
+                       m_unlock(&bindLock);
+                       return -1;
+               }
+               callBackPid = curPid;
+       }
+       m_unlock(&bindLock);
+       return 0;
+}
+
 int
 create_data_socket(int *dataFd, unsigned short *cbPort)
 {
@@ -1825,6 +1842,13 @@ dc_setExtraOption( char *s)
 
 }
 
+void dc_resetExtraOption()
+{
+	dc_debug(DC_INFO, "resetting extra option");
+	free(extraOption);
+	extraOption = NULL;
+}
+
 void dc_setOpenTimeout(time_t t)
 {
 	openTimeOut = t;
@@ -1994,3 +2018,30 @@ void dc_setClientActive()
 {
 	activeClient=1;
 }
+
+server * url2srv(dcap_url *url)
+{
+
+    server *srv;
+    char *tunnel;
+
+    srv = (server *) malloc(sizeof (server));
+    if (srv == NULL) {
+        dc_errno = DESYS;
+        return NULL;
+    }
+
+    srv->hostname = strdup(url->host);
+    srv->port = url->port;
+
+    if (url->prefix != NULL) {
+        tunnel = malloc(64);
+        tunnel[0] = '\0';
+        sprintf(tunnel, "lib%sTunnel.so", url->prefix);
+        srv->tunnel = addIoPlugin(tunnel);
+        free(tunnel);
+    } else {
+        srv->tunnel = NULL;
+    }
+    return srv;
+}
