@@ -39,6 +39,7 @@
 #include "dcap_lseek.h"
 #include "debug_level.h"
 #include "dcap_debug.h"
+#include "node_plays.h"
 
 #define MEMORY_PER_FILE_DEFAULT (1024*1024)
 #define MEMORY_PER_FILE_MINIMUM 1024
@@ -60,6 +61,7 @@ struct read_request {
 
 static void ensure_data_in_currentcb(struct read_request *request);
 static void establish_buffer_size( local_cache_buffer_t *lb);
+static void flush_cache( struct vsp_node *node);
 static void read_first_buffer(struct read_request *request);
 static ssize_t copy_data_from_currentcb(struct read_request *request);
 static void build_request( struct read_request *request, struct vsp_node *node,
@@ -102,6 +104,37 @@ static unsigned long global_stats_blocks_allocated;
 
 static int current_fd;
 
+
+/**
+ *  Flush any cached blocks.
+ */
+void dc_lcb_flush(int fd)
+{
+	struct vsp_node *node;
+
+	current_fd = fd;
+
+	emit_debug( "flushing LCB");
+
+#ifdef DC_CALL_TRACE
+	showTraceBack();
+#endif
+
+	/* nothing wrong ... yet */
+	dc_errno = DEOK;
+
+	node = get_vsp_node(fd);
+	if (node != NULL) {
+		if( node->lcb ) {
+			flush_cache(node);
+		}
+		m_unlock(&node->mux);
+	}
+}
+
+
+
+
 long dc_lcb_init( struct vsp_node *node ) {
 
     local_cache_buffer_t *lb = NULL;
@@ -195,16 +228,12 @@ long get_envvar( const char *envvar_name, long default_value,
 void dc_lcb_clean(struct vsp_node *node)
 {
     local_cache_buffer_t *lb = node->lcb;
-    cbindex_t *cb;
 
     current_fd = node->dataFd;
 
-    for( cb = lb->cbi; cb; cb = cb->next) {
-	free(cb->bpo);
-	update_global_stats_from_retired_cb(cb);
-    }
+    flush_cache(node);
 
-    emit_debug( "statistics: reads=%lu,  blocks=%lu,  hit ratio=%f \n",
+    emit_debug( "statistics: reads=%lu,  blocks=%lu,  hit ratio=%f",
 		global_stats_total_block_reads,
 		global_stats_blocks_allocated,
 		(double) global_stats_total_block_reads /
@@ -222,6 +251,25 @@ void update_global_stats_from_retired_cb(cbindex_t *cb)
 }
 
 
+void flush_cache( struct vsp_node *node)
+{
+    local_cache_buffer_t *lb = node->lcb;
+    cbindex_t *cb, *next;
+
+    for( cb = lb->cbi; cb; cb = next) {
+	free(cb->bpo);
+	cb->bpo = NULL;
+	next = cb->next;
+	cb->prev = NULL;
+	cb->next = NULL;
+	cb->bnum = 0;
+	update_global_stats_from_retired_cb(cb);
+    }
+
+    lb->nbcache = 0;
+}
+
+
 ssize_t dc_lcb_read( struct vsp_node * node, char *buf, ssize_t len)
 {
     local_cache_buffer_t *lb = node->lcb;
@@ -240,7 +288,8 @@ ssize_t dc_lcb_read( struct vsp_node * node, char *buf, ssize_t len)
 	ensure_data_in_currentcb(request);
 	bytes_copied = copy_data_from_currentcb(request);
 
-	if( bytes_copied < 0) {
+	// Consider zero bytes read as reaching EOF
+	if( bytes_copied <= 0) {
 	    break;
 	}
 
@@ -368,6 +417,9 @@ void update_currentcb_to_existing_cb(struct read_request *request,
 	emit_debug( "switching to buffer %lld nused %ld",
 		    new_current->bnum, new_current->nused );
     }
+
+    /* REVISIT: if re-reading a block created from a partial read,
+       we should attempt to re-read the block. */
 }
 
 void update_currentcb_by_reading(struct read_request *request,
@@ -557,18 +609,18 @@ ssize_t read_currentcb( struct read_request *request)
     cbindex_t *current = lb->currentcb;
     off64_t start_of_current = current->bnum * lb->buflen;
 
-    emit_debug( "reading %lld buffer %ld bytes",
-		current->bnum, lb->buflen);
+    emit_debug( "reading %ld bytes for block %lld at %lld ",
+		lb->buflen, current->bnum, start_of_current);
 
-    dc_real_lseek( node, start_of_current, SEEK_SET);
+    dc_real_lseek(node, start_of_current, SEEK_SET);
 
     current->blen = dc_real_read(node, current->bpo, lb->buflen);
 
     dc_real_lseek(node, request->fpos, SEEK_SET);
 
     if( current->blen < lb->buflen && request->remaining > current->blen) {
-	emit_debug( "short-read detected; requested %ld bytes at %ld "
-		    "but got %ld\n", lb->buflen, start_of_current,
+	emit_debug( "short-read detected; requested %ld bytes at %lld "
+		    "but got %ld", lb->buflen, start_of_current,
 		    current->blen);
     }
 
@@ -589,7 +641,7 @@ ssize_t copy_data_from_currentcb( struct read_request *request)
     available = current->blen - request->bpos;
 
     if( available <= 0) {
-	return -1;
+        return available == 0 ? 0 : -1;
     }
 
     copy_len = (request->remaining<available) ? request->remaining : available;
