@@ -434,11 +434,7 @@ ssize_t dc_readv(int fd, const struct iovec *vector, int count) {
 	/* nothing wrong ... yet */
 	dc_errno = DEOK;
 
-#ifdef IOV_MAX
-	if( (count == 0) || (count > IOV_MAX) ) {
-#else
-	if(count == 0) {
-#endif
+	if( (count < 0) || (count > IOV_MAX) ) {
 		errno = EINVAL;
 		return -1;
 	}
@@ -649,11 +645,7 @@ int dc_readv2(int fd, iovec2 *vector, int count) {
 		bPos = 0; /* position in current transfer block */
 		totalToRead = 0; /* byte to read in current chunk*/
 
-#ifdef IOV_MAX
 		vectorCount = ((count - vectorIndex) > IOV_MAX) ? IOV_MAX : (count - vectorIndex);
-#else
-		vectorCount = count - vectorIndex;
-#endif
 		dc_debug(DC_IO, "total to read %d, chunk %d, index %d", count, vectorCount, vectorIndex);
 
 		readvmsg = malloc(12 + vectorCount*12); /* header + for each request */
