@@ -26,10 +26,11 @@ typedef struct {
 	char *file;
 	int type;
 	char *prefix;
+        short port;
+        int need_brackets;
 } dcap_url;
 
 extern dcap_url *dc_getURL(const char *);
-extern char *url2config( char *, size_t, dcap_url *);
 extern int isUrl(const char *);
 
 #endif /* DCAP_URL_H */
